@@ -655,7 +655,10 @@ class TestConstructSetupPyFile:
 
 
 class TestBuildStandard:
-    def test_default(self, hatch, helpers, temp_dir):
+    def test_default(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -702,7 +705,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_default_no_reproducible(self, hatch, helpers, temp_dir):
+    def test_default_no_reproducible(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -726,7 +732,7 @@ class TestBuildStandard:
         build_path.mkdir()
 
         with project_path.as_cwd():
-            artifacts = list(builder.build(str(build_path)))
+            artifacts = list(builder.build(directory=str(build_path)))
 
         assert len(artifacts) == 1
         expected_artifact = artifacts[0]
@@ -750,7 +756,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime != get_reproducible_timestamp()
 
-    def test_default_support_legacy(self, hatch, helpers, temp_dir):
+    def test_default_support_legacy(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -774,7 +783,7 @@ class TestBuildStandard:
         build_path.mkdir()
 
         with project_path.as_cwd():
-            artifacts = list(builder.build(str(build_path)))
+            artifacts = list(builder.build(directory=str(build_path)))
 
         assert len(artifacts) == 1
         expected_artifact = artifacts[0]
@@ -795,7 +804,10 @@ class TestBuildStandard:
         )
         helpers.assert_files(extraction_directory, expected_files)
 
-    def test_default_build_script_artifacts(self, hatch, helpers, temp_dir):
+    def test_default_build_script_artifacts(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -845,7 +857,7 @@ class TestBuildStandard:
         build_path.mkdir()
 
         with project_path.as_cwd():
-            artifacts = list(builder.build(str(build_path)))
+            artifacts = list(builder.build(directory=str(build_path)))
 
         assert len(artifacts) == 1
         expected_artifact = artifacts[0]
@@ -866,7 +878,10 @@ class TestBuildStandard:
         )
         helpers.assert_files(extraction_directory, expected_files)
 
-    def test_default_build_script_extra_dependencies(self, hatch, helpers, temp_dir):
+    def test_default_build_script_extra_dependencies(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -917,7 +932,7 @@ class TestBuildStandard:
         build_path.mkdir()
 
         with project_path.as_cwd():
-            artifacts = list(builder.build(str(build_path)))
+            artifacts = list(builder.build(directory=str(build_path)))
 
         assert len(artifacts) == 1
         expected_artifact = artifacts[0]
@@ -938,7 +953,10 @@ class TestBuildStandard:
         )
         helpers.assert_files(extraction_directory, expected_files)
 
-    def test_include_project_file(self, hatch, helpers, temp_dir):
+    def test_include_project_file(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -987,7 +1005,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_project_file_always_included(self, hatch, helpers, temp_dir):
+    def test_project_file_always_included(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1045,7 +1066,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_config_file_always_included(self, hatch, helpers, temp_dir):
+    def test_config_file_always_included(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1105,7 +1129,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_include_readme(self, hatch, helpers, temp_dir):
+    def test_include_readme(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1152,7 +1179,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_readme_always_included(self, hatch, helpers, temp_dir):
+    def test_readme_always_included(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1206,7 +1236,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_include_license_files(self, hatch, helpers, temp_dir):
+    def test_include_license_files(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1253,7 +1286,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_license_files_always_included(self, hatch, helpers, temp_dir):
+    def test_license_files_always_included(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1307,7 +1343,10 @@ class TestBuildStandard:
         stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
 
-    def test_default_vcs_git_exclusion_files(self, hatch, helpers, temp_dir):
+    def test_default_vcs_git_exclusion_files(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1341,7 +1380,7 @@ class TestBuildStandard:
         build_path.mkdir()
 
         with project_path.as_cwd():
-            artifacts = list(builder.build(str(build_path)))
+            artifacts = list(builder.build(directory=str(build_path)))
 
         assert len(artifacts) == 1
         expected_artifact = artifacts[0]
@@ -1362,7 +1401,10 @@ class TestBuildStandard:
         )
         helpers.assert_files(extraction_directory, expected_files)
 
-    def test_default_vcs_mercurial_exclusion_files(self, hatch, helpers, temp_dir):
+    def test_default_vcs_mercurial_exclusion_files(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1410,7 +1452,7 @@ class TestBuildStandard:
         build_path.mkdir()
 
         with project_path.as_cwd():
-            artifacts = list(builder.build(str(build_path)))
+            artifacts = list(builder.build(directory=str(build_path)))
 
         assert len(artifacts) == 1
         expected_artifact = artifacts[0]
@@ -1431,7 +1473,10 @@ class TestBuildStandard:
         )
         helpers.assert_files(extraction_directory, expected_files)
 
-    def test_no_strict_naming(self, hatch, helpers, temp_dir):
+    def test_no_strict_naming(self, hatch, helpers, temp_dir, config_file):
+        config_file.model.template.plugins['default']['src-layout'] = False
+        config_file.save()
+
         project_name = 'My.App'
 
         with temp_dir.as_cwd():
@@ -1471,9 +1516,9 @@ class TestBuildStandard:
             tar_archive.extractall(str(extraction_directory))
 
         expected_files = helpers.get_template_files(
-            'sdist.standard_default', project_name, relative_root=builder.project_id
+            'sdist.standard_default', project_name, relative_root=builder.artifact_project_id
         )
         helpers.assert_files(extraction_directory, expected_files)
 
-        stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
+        stat = os.stat(str(extraction_directory / builder.artifact_project_id / 'PKG-INFO'))
         assert stat.st_mtime == get_reproducible_timestamp()
