@@ -9,7 +9,7 @@ from hatch.python.core import PythonManager
 from hatch.python.resolve import get_compatible_distributions
 from hatch.utils.fs import Path
 from hatch.utils.structures import EnvVars
-from hatchling.utils.constants import DEFAULT_CONFIG_FILE
+from hatchling.utils.constants import DEFAULT_BUILD_SCRIPT, DEFAULT_CONFIG_FILE
 
 
 @pytest.fixture(scope='module')
@@ -435,7 +435,7 @@ def test_sync_project_features(hatch, helpers, temp_dir, config_file):
 
 
 @pytest.mark.requires_internet
-def test_dependency_hash_checking(hatch, helpers, temp_dir, config_file):
+def test_dependency_hash_checking(hatch, helpers, temp_dir, config_file, mocker):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
@@ -507,6 +507,7 @@ def test_dependency_hash_checking(hatch, helpers, temp_dir, config_file):
     assert output_file.is_file()
 
     assert str(output_file.read_text()) == "(1.0, 'KiB')"
+    output_file.unlink()
 
     # Now there should be no output because there is no dependency checking
     with project_path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
@@ -524,6 +525,49 @@ def test_dependency_hash_checking(hatch, helpers, temp_dir, config_file):
     assert output_file.is_file()
 
     assert str(output_file.read_text()) == "(1.0, 'KiB')"
+    output_file.unlink()
+
+    mocker.patch('hatch.env.virtual.VirtualEnvironment.dependencies_in_sync', return_value=False)
+    mocker.patch('hatch.env.virtual.VirtualEnvironment.dependency_hash', side_effect=['foo', 'bar', 'bar'])
+
+    # Ensure that the saved value is the second value
+    with project_path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
+        result = hatch(
+            'run',
+            'python',
+            '-c',
+            "import binary,pathlib,sys;pathlib.Path('test.txt').write_text(str(binary.convert_units(1024)))",
+        )
+
+    assert result.exit_code == 0, result.output
+    assert result.output == helpers.dedent(
+        """
+        Checking dependencies
+        Syncing dependencies
+        """
+    )
+
+    output_file = project_path / 'test.txt'
+    assert output_file.is_file()
+
+    assert str(output_file.read_text()) == "(1.0, 'KiB')"
+    output_file.unlink()
+
+    with project_path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
+        result = hatch(
+            'run',
+            'python',
+            '-c',
+            "import binary,pathlib,sys;pathlib.Path('test.txt').write_text(str(binary.convert_units(1024)))",
+        )
+
+    assert result.exit_code == 0, result.output
+    assert not result.output
+
+    output_file = project_path / 'test.txt'
+    assert output_file.is_file()
+
+    assert str(output_file.read_text()) == "(1.0, 'KiB')"
 
 
 def test_scripts(hatch, helpers, temp_dir, config_file):
@@ -2191,3 +2235,90 @@ def test_update_python_max_compatible(hatch, helpers, temp_dir, config_file, moc
     assert env_path.name == project_path.name
 
     assert str(env_path) in str(output_file.read_text())
+
+
+@pytest.mark.requires_internet
+def test_python_installation_with_metadata_hook(
+    hatch, helpers, temp_dir, config_file, mocker, available_python_version
+):
+    config_file.model.template.plugins['default']['tests'] = False
+    config_file.save()
+
+    project_name = 'My.App'
+
+    with temp_dir.as_cwd():
+        result = hatch('new', project_name)
+
+    assert result.exit_code == 0, result.output
+
+    project_path = temp_dir / 'my-app'
+    data_path = temp_dir / 'data'
+    data_path.mkdir()
+
+    project = Project(project_path)
+    config = dict(project.raw_config)
+    config['build-system']['requires'].append('foo')
+    config['tool']['hatch']['metadata'] = {'hooks': {'custom': {'dependencies': ['binary']}}}
+    project.save_config(config)
+
+    helpers.update_project_environment(
+        project,
+        'default',
+        {'skip-install': True, 'python': available_python_version, **project.config.envs['default']},
+    )
+
+    build_script = project_path / DEFAULT_BUILD_SCRIPT
+    build_script.write_text(
+        helpers.dedent(
+            """
+            from hatchling.metadata.plugin.interface import MetadataHookInterface
+
+            class CustomMetadataHook(MetadataHookInterface):
+                def update(self, metadata):
+                    import binary
+            """
+        )
+    )
+
+    mocker.patch('hatch.env.virtual.VirtualEnvironment._interpreter_is_compatible', return_value=False)
+    manager = PythonManager(data_path / 'env' / 'virtual' / '.pythons')
+    assert not manager.get_installed()
+
+    with project_path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
+        result = hatch(
+            'run', 'python', '-c', "import os,sys;open('test.txt', 'a').write(sys.executable+os.linesep[-1])"
+        )
+
+    assert result.exit_code == 0, result.output
+    assert result.output == helpers.dedent(
+        f"""
+        Creating environment: default
+        Installing Python distribution: {available_python_version}
+        Checking dependencies
+        """
+    )
+    output_file = project_path / 'test.txt'
+    assert output_file.is_file()
+
+    env_data_path = data_path / 'env' / 'virtual'
+    assert env_data_path.is_dir()
+
+    project_data_path = env_data_path / project_path.name
+    assert project_data_path.is_dir()
+
+    storage_dirs = list(project_data_path.iterdir())
+    assert len(storage_dirs) == 1
+
+    storage_path = storage_dirs[0]
+    assert len(storage_path.name) == 8
+
+    env_dirs = list(storage_path.iterdir())
+    assert len(env_dirs) == 1
+
+    env_path = env_dirs[0]
+
+    assert env_path.name == project_path.name
+
+    assert str(env_path) in str(output_file.read_text())
+
+    assert list(manager.get_installed()) == [available_python_version]
