@@ -2,17 +2,14 @@ from hatch.template import File
 from hatch.utils.fs import Path
 from hatchling.metadata.spec import DEFAULT_METADATA_VERSION
 
-from ..new.default import get_files as get_template_files
+from ..new.feature_no_src_layout import get_files as get_template_files
 
 
 def get_files(**kwargs):
     relative_root = kwargs.get('relative_root', '')
 
-    files = []
-    for f in get_template_files(**kwargs):
-        files.append(File(Path(relative_root, f.path), f.contents))
-
-    files.append(
+    files = [File(Path(relative_root, f.path), f.contents) for f in get_template_files(**kwargs)]
+    files.extend((
         File(
             Path(relative_root, 'PKG-INFO'),
             f"""\
@@ -21,9 +18,7 @@ Name: {kwargs['project_name']}
 Version: 0.0.1
 License-File: LICENSE.txt
 """,
-        )
-    )
-    files.append(
+        ),
         File(
             Path(relative_root, 'setup.py'),
             f"""\
@@ -39,7 +34,7 @@ setup(
     ],
 )
 """,
-        )
-    )
+        ),
+    ))
 
     return files
